import React, { useState } from "react";
import { useMediaQuery } from 'react-responsive'
import styled from "styled-components";
import Brand from "./Brand/index"
import PrimaryNavLinks from "./PrimaryNavLinks/index";
import media from 'css-in-js-media';
import SecondaryNavLinks from "./SecondaryNavLinks/index"
import HamburgerMenu from 'react-hamburger-menu';
import TinyTopNav from "./TinyTopNav";

export const PrimaryNavContainer = styled.div`
  display: flex;
  padding: 0;
  align-items: center;
  margin-left: 40px;
  margin-top: 4px;
  margin-bottom: -1px;
  color: 'hsl(221, 93%, 16%)';
  z-index: 20;


  ${media('<desktop')} {
    margin-left: 5px;
    margin-top: 5px;
  }
`;

const DesktopNav = styled.nav`
  position: fixed;
  top: 41px;
  display: flex;
  flex-flow: row nowrap;
  align-items: center;
  position: relative;
  box-shadow: rgb(3 27 78 / 10%) 0px 2px 4px;
  background: #fff;
  align-items: center;
  width: 100%;
  height: 64px;
  z-index: 4;

  @media screen and (max-width: 768px) {
    justify-content: space-between;
    padding: 0 30px;
  }

  ${media('<desktop')} {
    top: 0;
  }


  .logo {
    flex: .15;
    color: var(--text);
    font-size: 32px;
  }

  .nav-links {
    @media screen and (max-width: 768px) {
    }
  }

  .hamburger {
    position: absolute !important;
    right: 20px;
`;

export const SecondaryNavContainer = styled.div`
  position: absolute;
  right: 0;
`

export const MobileContainer = styled.div`
  width: 80%;
  display: flex;
  position: absolute;
  flex-direction: column;
  background-color: #fff;
  box-shadow: 0 8px 16px rgb(10 10 10 / 10%);
  padding: 2rem 0;

  @media screen and (max-width: 1023px) {
    left: 20px;
    top: 65px;
    width: 90%;
  }
`

const DesktopNavbar = ({data, location})  => {
  const { navigation } = data.prismic;
  console.log(data);

  const [isMobileNavOpen, setIsMobileNavOpen] = useState(false);
  const isDesktop = useMediaQuery({ minWidth: 1024 })
  const isMobile = useMediaQuery({ maxWidth: 1023 })


  const Desktop = ({ children }) => {
    return isDesktop ? children : null
  }

  const Mobile = ({ children, display }) => {
    return isMobile ?
    <div style={{ display }}>{children}</div> : null
  }

  return (
    <>
    <DesktopNav>
    <TinyTopNav navigation={navigation}/>
      {Brand(navigation)}
      <Desktop>
        <PrimaryNavContainer>
          {PrimaryNavLinks(navigation, location)}
        </PrimaryNavContainer>
        <SecondaryNavContainer>
        {SecondaryNavLinks(navigation)}
        </SecondaryNavContainer>
      </Desktop>
      <Mobile display={isMobileNavOpen ? 'block' : 'none'}>
         <MobileContainer>
          {PrimaryNavLinks(navigation, location)}
          {SecondaryNavLinks(navigation)}
        </MobileContainer>
      </Mobile>
      {isMobile && <HamburgerMenu className="hamburger" color="#5b6987" width={18} height={12} isOpen={isMobileNavOpen} menuClicked={() => {setIsMobileNavOpen(!isMobileNavOpen)}}></HamburgerMenu> }
    </DesktopNav>
    </>
  );
};

export default DesktopNavbar;



