/* eslint-disable camelcase */
/* eslint-disable array-callback-return */
import React, { useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components'

import { ProductsMegaMenu, CommunityMegaMenu, SolutionsMegaMenu } from './MegaMenus';

// LazyLink
import { HandleClear } from './MegaMenus/atoms';
import Element from '../../element';
import media from 'css-in-js-media';

export const StyledPrimaryNavLink = styled(Element)`
  color: hsl(221, 93%, 16%);
  background-color: transparent !important;
  font-family: 'Inter-Medium', 'Helvetica', 'san-serif';
  font-size: 14px !important;
  padding: 1.35rem .75rem;

  ${media('<desktop')} {
    font-size: 18px !important;
    border-bottom: 1px solid hsl(218, 18%, 91%);
    margin-bottom: 10px;
    margin-left: 15px;
    margin-right: 15px;
    padding: 5px 0 15px 0;
  }
`;

const PrimaryNavLinks = (navigation, location, linkType) => {
  const [isMegaMenuOpen, setIsMegaMenuOpen] = useState(false);
  const [currentMegaMenu, setCurrentMegaMenu] = useState('');
  const { primary_navigation_links } = navigation;

  const determineMegaMenuActiveState = () => {
    const currentPaths =
      window && window.location && window.location.pathname.split('/').filter(path => path !== '');
    if((currentPaths.length <= 0 )) return null;
    if ((currentPaths && currentPaths[0].toLowerCase() === 'solutions') || (currentPaths && currentPaths[0] === 'business')) {
      return 'solutions';
    }
    if (currentPaths && currentPaths[0].toLowerCase() === 'products' && currentPaths && currentPaths[1] !== 'marketplace') {
      return 'products';
    }
    if ((currentPaths && currentPaths[0].toLowerCase() === 'open-source') || (currentPaths && currentPaths[0] === 'hatch')) {
      return 'community';
    }
    return null;
  };

  const openCurrentMegaMenu = (megaMenuName) => {
    if(isMegaMenuOpen) return setCurrentMegaMenu(megaMenuName);

    setCurrentMegaMenu(megaMenuName);
    setIsMegaMenuOpen(true);
  }

  const closeMegaMenu = () => {
    setIsMegaMenuOpen(false);
    setCurrentMegaMenu('');
  }

  const currentPath = determineMegaMenuActiveState();

  const checkForMegaMenu = item => {
    switch (item.primary_navigation_text) {
      case 'Products': {
        return ProductsMegaMenu(item, navigation, currentPath, openCurrentMegaMenu, closeMegaMenu, isMegaMenuOpen, currentMegaMenu);
      }
      case 'Community': {
        return CommunityMegaMenu(item, navigation, currentPath, openCurrentMegaMenu, closeMegaMenu, isMegaMenuOpen, currentMegaMenu);
      }
      case 'Solutions': {
        return SolutionsMegaMenu(item, navigation, currentPath, openCurrentMegaMenu, closeMegaMenu, isMegaMenuOpen, currentMegaMenu);
      }
      default:

      //NOTE
        return (
          <StyledPrimaryNavLink
            href={item.primary_navigation_link && item.primary_navigation_link.url}
            key={item.primary_navigation_text}
            renderAs='a'
            activeStyle={{ borderBottom: '2px solid #0069ff', padding: '20px 12px 18px' }}
          >
            {item.primary_navigation_text}
          </StyledPrimaryNavLink>
        );
    }
  };

  return primary_navigation_links.map(checkForMegaMenu);
};

export default PrimaryNavLinks;

PrimaryNavLinks.propTypes = {
  navigation: PropTypes.node.isRequired,
};
